@@ -71,7 +71,7 @@ define ([
             'menuText': 'My profile',
             'aclProfile': 'passerby',
             'start': dactionStart('myProfileAction'),
-            'pushable': true
+            'pushable': false
         });
         target.push('empProfileEditSave', {
             'name': 'empProfileEditSave',
@@ -221,7 +221,7 @@ define ([
             'menuText': 'Lookup',
             'aclProfile': 'admin',
             'start': dactionStart('actionSchedLookup'),
-            'pushable': true
+            'pushable': false
         });
         target.push('createSchedule', {
             'name': 'createSchedule',
@@ -231,6 +231,14 @@ define ([
             'start': dactionStart('createSchedule'),
             'pushable': false
         });
+        target.push('actionDisplaySchedule', {
+            'name': 'actionDisplaySchedule',
+            'type': 'daction',
+            'menuText': 'Display',
+            'aclProfile': 'inactive',
+            'start': dactionStart('actionDisplaySchedule'),
+            'pushable': false
+        });
         target.push('schedEditSave', {
             'name': 'schedEditSave',
             'type': 'daction',
