@@ -44,6 +44,7 @@ define ([
     "jquery",
     "current-user",
     "app/emp-lib",
+    "app/ldap-lib",
     "app/priv-lib",
     "app/sched-history-lib",
     "app/sched-lib",
@@ -56,6 +57,7 @@ define ([
     $,
     currentUser,
     empLib,
+    ldapLib,
     privLib,
     schedHistLib,
     schedLib,
@@ -79,15 +81,17 @@ define ([
             start.dbrowserListen();
         },
 
-        // actions triggered from Employee menu
+        // Employee, non-LDAP actions
         "myProfileAction": empLib.myProfileAction,
         "empProfileEditSave": empLib.empProfileEditSave,
-        "ldapLookupSubmit": empLib.ldapLookupSubmit,
-        "ldapSync": empLib.ldapSync,
-        "ldapSyncFromBrowser": empLib.ldapSyncFromBrowser,
         "actionEmplSearch": empLib.actionEmplSearch,
         "masqEmployee": empLib.masqEmployee,
 
+        // Employee LDAP actions
+        "ldapLookupSubmit": ldapLib.ldapLookupSubmit,
+        "ldapSync": ldapLib.ldapSync,
+        "ldapSyncFromBrowser": ldapLib.ldapSyncFromBrowser,
+
         // actions triggered from Priv (status) menu
         "actionPrivHistory": privLib.actionPrivHistory,
         "actionPrivHistoryEdit": privLib.actionPrivHistoryEdit,
@@ -104,6 +108,7 @@ define ([
         "browseAllSchedules": schedLib.browseAllSchedules,
         "actionSchedLookup": schedLib.actionSchedLookup,
         "createSchedule": schedLib.createSchedule,
+        "actionDisplaySchedule": schedLib.actionDisplaySchedule,
         "schedEditSave": schedLib.schedEditSave,
         "schedReallyDelete": schedLib.schedReallyDelete,
 
