@@ -45,7 +45,7 @@ define ([
 ], function (
   QUnit,
   $,
-  cannedTests,
+  ct,
   login,
   loggout,
 ) {
@@ -64,12 +64,12 @@ define ([
                 cu;
             login({"nam": "root", "pwd": "immutable"});
             setTimeout(function () {
-                cannedTests.login(assert, "root", "admin");
+                ct.login(assert, "root", "admin");
                 loggout();
                 done();
             }, 500);
             setTimeout(function () {
-                cannedTests.loggout(assert);
+                ct.loggout(assert);
                 done();
             }, 1000);
         });
